@@ -255,6 +255,10 @@ gconf_property_editor_set_prop (GObject      *object,
 		client = gconf_client_get_default ();
 		cb = g_value_get_pointer (value);
 		peditor->p->callback = (GConfClientNotifyFunc) cb;
+		if (peditor->p->handler_id != 0) {
+			gconf_client_notify_remove (client,
+						    peditor->p->handler_id);
+		}
 		peditor->p->handler_id =
 			gconf_client_notify_add (client, peditor->p->key,
 						 peditor->p->callback,
@@ -330,7 +334,7 @@ gconf_property_editor_finalize (GObject *object)
 	if (gconf_property_editor->p->data_free_cb)
 		gconf_property_editor->p->data_free_cb (gconf_property_editor->p->data);
 
-	if (gconf_property_editor->p->handler_id != 0) {
+ 	if (gconf_property_editor->p->handler_id != 0) {
 		GConfClient *client;
 
 		client = gconf_client_get_default ();		
@@ -393,6 +397,12 @@ gconf_property_editor_get_key (GConfPropertyEditor *peditor)
 	return peditor->p->key;
 }
 
+GObject *
+gconf_property_editor_get_ui_control (GConfPropertyEditor  *peditor)
+{
+	return peditor->p->ui_control;
+}
+
 static void
 peditor_set_gconf_value (GConfPropertyEditor *peditor,
 			 const gchar         *key,
